changeset 2161:7219cdce7bba

spelling: negociate -> negotiate
author Sebastien Jodogne <s.jodogne@gmail.com>
date Mon, 21 Nov 2016 09:19:53 +0100
parents 2f2de941dff7
children d738945c25cd
files OrthancServer/DicomProtocol/DicomUserConnection.cpp Resources/DicomConformanceStatement.txt
diffstat 2 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/Resources/DicomConformanceStatement.txt	Sun Nov 20 21:45:43 2016 +0100
+++ b/Resources/DicomConformanceStatement.txt	Mon Nov 21 09:19:53 2016 +0100
@@ -203,7 +203,7 @@
 Transfer Syntaxes
 -----------------
 
-Orthanc will accept and negociate presentation contexts for all of the
+Orthanc will accept and negotiate presentation contexts for all of the
 abovementioned supported SOP Classes using any of the following
 transfer syntaxes:
--- a/OrthancServer/DicomProtocol/DicomUserConnection.cpp	Sun Nov 20 21:45:43 2016 +0100
+++ b/OrthancServer/DicomProtocol/DicomUserConnection.cpp	Mon Nov 21 09:19:53 2016 +0100
@@ -280,21 +280,21 @@
     const std::string syntax(xfer.getXferID());
     bool isGeneric = IsGenericTransferSyntax(syntax);
 
-    bool renegociate;
+    bool renegotiate;
     if (isGeneric)
     {
       // Are we making a generic-to-specific or specific-to-generic change of
       // the transfer syntax? If this is the case, renegotiate the connection.
-      renegociate = !IsGenericTransferSyntax(connection.GetPreferredTransferSyntax());
+      renegotiate = !IsGenericTransferSyntax(connection.GetPreferredTransferSyntax());
     }
     else
     {
       // We are using a specific transfer syntax. Renegociate if the
       // current connection does not match this transfer syntax.
-      renegociate = (syntax != connection.GetPreferredTransferSyntax());
+      renegotiate = (syntax != connection.GetPreferredTransferSyntax());
     }
 
-    if (renegociate)
+    if (renegotiate)
     {
       LOG(INFO) << "Change in the transfer syntax: the C-Store associated must be renegotiated";
 
@@ -280,21 +280,21 @@
     else
     {
-      // We are using a specific transfer syntax. Renegociate if the
+      // We are using a specific transfer syntax. Renegotiate if the
       // current connection does not match this transfer syntax.